<?php
namespace Teknisa\COZ\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class SubstituicaoPrato extends \Teknisa\GER\Controllers\TeknisaCrud
{

    protected $crudService;
    protected $entityManager;
    protected $util;

    public function __construct(
        $crudService, $parameterBag, $entityManager, $util
    )
    {
        parent::__construct($crudService, $parameterBag);
        $this->entityManager = $entityManager;
        $this->util = $util;
    }

    public function salvaSubsProduto( DTO\Request\DataSet $request, DTO\Response $response){
        
        try{
            $connection = $this->entityManager->getConnection();
            
            $operador = $this->crudService->getEnvironment()->getCdOperador();
            $nrorg = $this->crudService->getEnvironment()->getNrOrg();

            $dataSet = $request->getDataSet()->getRows();
            $produto = $dataSet[0];
            $novoProduto =  $dataSet[1];
            $produto['FILIAL'] = (is_array($novoProduto['NMFILIAL'])) ? implode("_", $novoProduto['NMFILIAL']) : 'T';
            if(empty($novoProduto['NMFILISERV'])) $novoProduto['NMFILISERV'] = $this->getFiliservProd($produto);
            $nrlista = $this->util->insertLista($novoProduto['NMFILISERV']);
            $cdprodorigem = $this->concatenaValores($produto);
            $cancelaTodos = null;
            $naosubstituido = '';
            
            $procedureSubst = new \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure($connection, 'SUBST_PROD_PRODUCAO');

            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NRPLANPROD',        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $produto['NRPLANPROD'],        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CANCELATODOS',      \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $cancelaTodos,                 \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NRLISTA',           \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $nrlista,                      \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDCENTRAL',         \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $produto['CDFILCENT'],         \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDOPERADOR',        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $operador,                     \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NRORG',             \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $nrorg,                        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDPRODORIGEM',      \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $cdprodorigem,                 \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDPRATO_SEL',       \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $novoProduto['CDPRATO'],       \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDFILAUXPRAT_SEL',  \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $novoProduto['CDFILAUXPRAT'],  \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NAOSUBSTITUIDO',       \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_OUTPUT, $naosubstituido,                 \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR, 200));

            $naosubstituido = $procedureSubst->execute();
            $msg = $this->getMesageProcedure($naosubstituido);
            $this->util->deleteLista($nrlista);
            $response->addDataset(new DataSet('naosubstituido', $msg));
        }catch(\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }

    }
    public function getMesageProcedure($naosubstituido){
        $arrFiliServ = explode("_", $naosubstituido['P_NAOSUBSTITUIDO']);
        $msg = array();
        $sql = "SELECT F.NMFILIAL, S.NMSERVICO FROM FILIAL F INNER JOIN SERVICO S ON S.CDFILIAL = F.CDFILIAL AND S.NRORG = F.NRORG WHERE F.CDFILIAL = :CDFILIAL AND S.CDSERVFILI = :CDSERVFILI";
        foreach($arrFiliServ as $data){
            if($data != null){
                $unidade = substr($data, 0, 4);
                $servico = substr($data, 4, 9);
                $params = array(
                    'CDFILIAL'   => $unidade,
                    'CDSERVFILI' => $servico
                );
                $dataSql = $this->entityManager->getConnection()->fetchAll($sql, $params);
                
                $preMsg = 'Unidade: '. $unidade. ' - '. $dataSql[0]['NMFILIAL']. ' | Serviço: '. $servico. ' - '. $dataSql[0]['NMSERVICO'];
                array_push($msg, $preMsg);
            }
        }
        return $msg;
    }

    public function getFiliservProd ($produto){
        $conditions = [
                array(
                    "columnName" => 'CDCENTRAL',
                    "operator"   => '=',
                    "value"      => $produto['CDFILCENT']
                ),
                array(
                    "columnName" => 'NRPLANPROD',
                    "operator"   => '=',
                    "value"      => $produto['NRPLANPROD']
                ),
                array(
                    "columnName" => "CDPRODACABADO",
                    "operator"   => '=',
                    "value"      => $produto['CDPRODUTO']
                ),
                array(
                    "columnName" => 'CDFILIAL',
                    "operator"   => '=',
                    "value"      => $produto['FILIAL']
                ),
                array(
                    "columnName" => 'IDCOOKCHILL',
                    "operator"   => '=',
                    "value"      => $produto['IDCOOKCHILL']
                ),
                array(
                    "columnName" => 'IDFINALIZACAO',
                    "operator"   => '=',
                    "value"      => $produto['IDFINALIZACAO']
                ),
                array(
                    "columnName" => 'IDTPPRODCHILL',
                    "operator"   => '=',
                    "value"      => $produto['IDTPPRODCHILL']
                ),
                array(
                    "columnName" => 'IDESTADO',
                    "operator"   => '=',
                    "value"      => $produto['IDESTADO']
                ),
                array(
                    "columnName" => 'NRSEQPRODACABADO',
                    "operator"   => '=',
                    "value"      => $produto['NRSEQPRODACABADO']
                )
        ];
        
        $dataSet = $this->crudService->getFilteredDataSet("pla10500_unidade_servico_prod", $conditions);  
        $rows = $dataSet->getRows();
        $cdfiliserv = array();
        foreach ($rows as $row) {
            array_push($cdfiliserv, $row['CDFILISERV']);
        }
        return $cdfiliserv;
    }
    
    public function cancelaSubsProduto( DTO\Request\Row $request, DTO\Response $response){
       
       try{
            $row = $request->getRow();
            
            $cdprodorigem = $this->concatenaValores($row);
            $connection = $this->entityManager->getConnection();
            $operador = $this->crudService->getEnvironment()->getCdOperador();
            $nrorg = $this->crudService->getEnvironment()->getNrOrg();
            $row['FILIAL'] = 'T';
            $row['NMFILISERV'] = $this->getFiliservProd($row);
            $nrlista = $this->util->insertLista($row['NMFILISERV']);
            
            $naosubstituido = '';
            $procedureSubst = new \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure($connection, 'SUBST_PROD_PRODUCAO');
            
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NRPLANPROD',        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['NRPLANPROD'],       \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CANCELATODOS',      \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['CANCELATODOS'],     \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NRLISTA',           \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $nrlista,                 \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDCENTRAL',         \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['CDFILCENT'],        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDOPERADOR',        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $operador,                \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NRORG',             \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $nrorg,                   \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDPRODORIGEM',      \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $cdprodorigem,            \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDPRATO_SEL',       \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['CDPRATOORI'],       \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDFILAUXPRAT_SEL',  \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['CDFILAUXPRATORI'],  \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureSubst->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NAOSUBSTITUIDO',       \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_OUTPUT, $naosubstituido,            \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR, 1));
            
            // var_dump($procedureSubst);die;
            $naosubstituido = $procedureSubst->execute();
            $response->addDataset(new DataSet('naosubstituido', $naosubstituido));
        }catch(\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
            
    }
    
    public function atualizaCardapio( DTO\Request\Row $request, DTO\Response $response){
        
       try{
            $connection = $this->entityManager->getConnection();
           // $connection->beginTransaction();
            
            $rows = $request->getRow();
            
            foreach($rows as $row){
                if($row['IDORIGEM'] == 'SUBSTITUTO' AND $row['CDPRATOORI']){    
                    $semCardapio = $this->verificaCardapio($row);
                    
                    if (count($semCardapio) > 0) {
                        $mensagem = array("Prato de Origem (produto acabado: " . $row['CDPRODUTO'] . ") não existe no(s) cardápio(s) a seguir: ");
                        foreach ($semCardapio as $cardapio) {
                            $data = ($cardapio['DTCARDAPIO']) ? explode(' ', $cardapio['DTCARDAPIO'])[0] : "(cardápio excluído)";
                            $erro = "Unidade: " . $cardapio['NMFILIAL'] . " - Serviço: " . $cardapio['NMSERVICO'] . " - Data: " . $data;
                            array_push($mensagem, $erro);
                        }
                                    
                        return $response->setError(new DTO\Response\Error($mensagem, 1));
                    }
                }
            }
            
            $cdoperador = $this->crudService->getEnvironment()->getCdOperador(); 
            $atualizado = $erros  = [];
            
            foreach ($rows as $row) {
               
               if($row['IDORIGEM'] == 'SUBSTITUTO' AND $row['CDPRATOORI']){
                
                    $nrplanprod = $row['NRPLANPROD'];
               
                    $data = $this->dataCard($row);
                    $dtInicial = substr($data['DTINICARD'],0,10);
                    $dtFinal = substr($data['DTFINCARD'],0,10);
                    
                    $listas = $this->listaFiliServ($row);
                    $listaServ = $listas[0];
                    $listaFili = array_unique($listas[1]);
                    $cdListaServ = $this->util->insertLista($listaServ);
                    $cdListaFili = $this->util->insertLista($listaFili);
                    
                    $nrlogintcard = '';
//var_dump($cdListaFili, $cdListaServ, $dtInicial, $dtFinal, $row, $cdoperador, $nrlogintcard);die;
                    $procedure = new StoredProcedure($connection, 'TROCA_PRATO_CARD');
                    $procedure->addParam(new Param('P_LISTAFILI',    Param::PARAM_INPUT, $cdListaFili,            Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_LISTASERV',    Param::PARAM_INPUT, $cdListaServ,            Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_DTINICIAL',    Param::PARAM_INPUT, $dtInicial,              Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_DTFINAL',      Param::PARAM_INPUT, $dtFinal,                Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_CDPRATORIG',   Param::PARAM_INPUT, $row['CDPRATOORI'],      Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_CDFAPRATORIG', Param::PARAM_INPUT, $row['CDFILAUXPRATORI'], Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_CDPRATDEST',   Param::PARAM_INPUT, $row['CDPRATO'],         Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_CDFAPRATDEST', Param::PARAM_INPUT, $row['CDFILAUXPRAT'],    Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_MODOPROC',     Param::PARAM_INPUT, "M",                     Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_CDNVPRODUTO',  Param::PARAM_INPUT, $row['CDNVPRODUTO'],     Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_CDOPERADOR',   Param::PARAM_INPUT, $cdoperador,             Param::PARAM_TYPE_STR));
                    $procedure->addParam(new Param('P_NRLOGINTCARD', Param::PARAM_OUTPUT, $nrlogintcard,          Param::PARAM_TYPE_STR, 10));
                    $nrlogintcard = $procedure->execute();
                    
                    if(isset($nrlogintcard["P_NRLOGINTCARD"])){
                        array_push($erros, ($nrlogintcard["P_NRLOGINTCARD"]."_".$row['CDPRATO']));
                    } else {
                        array_push($atualizado, ($row['CDPRATOORI'].$row['CDFILAUXPRATORI']));
                    }
                    $this->util->deleteLista($cdListaServ);
                    $this->util->deleteLista($cdListaFili);
               }
            }
            
            if (count($erros) == 0) {
                foreach ($atualizado as $k => $atual) {
                    $sql = "UPDATE PLANPRODACABADO
                               SET CDPRATOORI = '', CDFILAUXPRATORI = ''
                             WHERE NRPLANPROD =:NRPLANPROD 
                               AND CDPRATOORI || CDFILAUXPRATORI = :CDPRATOORICDFILAUXPRATORI";
                    
                    $query = $this->entityManager->getConnection()->prepare($sql);
                    $query->bindValue("NRPLANPROD", $nrplanprod);
                    $query->bindValue("CDPRATOORICDFILAUXPRATORI", $atual);
                    $query->execute();  
                }
            }
            
           // $connection->commit();
            $response->addDataset(new DataSet('erros', $erros));
            
         } catch(\Exception $e) {
            //$connection->rollBack();
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function erroLogintcard(DTO\Request\Row $request, DTO\Response $response){
        $erros = [];
        $rows = $request->getRow();
        foreach($rows as $row){
            $nrlogin = explode("_",$row);
            $sql = "SELECT DISTINCT L.IDNUMERRO, L.CDFILDESTLOG, F.NMFILIAL, L.CDSERDESTLOG, S.NMSERVICO, L.CDFILORIGLOG, P.NMPRATO FROM LOGINTCARD L
                        INNER JOIN FILIAL F ON F.CDFILIAL = L.CDFILDESTLOG
                        INNER JOIN SERVICO S ON S.CDFILIAL = L.CDFILDESTLOG AND S.CDSERVFILI = L.CDSERDESTLOG AND S.IDSERVATIV = 'S'
                        INNER JOIN PRATO P ON P.CDPRATO = :CDPRATO
                    WHERE NRLOGINTCARD =:NRLOGINTCARD";
            $params = [
                "NRLOGINTCARD"     => $nrlogin[0],
                "CDPRATO"     => $nrlogin[1]
            ];
            $data = $this->entityManager->getConnection()->fetchAll($sql, $params);    
            foreach($data as $row){
                array_push($erros,$row);    
            }
                
        }
        
        $response->addDataset(new DataSet('erros', $erros));
        
    }
    
    public function validaCancelamento( DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        $sql = "SELECT CDPRODACABADO, CDPRATO, CDFILAUXPRAT, IDFINALIZACAO, IDTPPRODCHILL, IDESTADO, NRSEQPRODACABADO 
                FROM PLANPRODACABADO WHERE NRPLANPROD =:NRPLANPROD AND CDPRATOORI =:CDPRATOORI";
        $params = array(
             "NRPLANPROD"   => $row['NRPLANPROD'],
             "CDPRATOORI"   => $row['CDPRATOORI']
        );
        
        $data = $this->entityManager->getConnection()->fetchAll($sql, $params);
        $response->addDataset(new DataSet('produtosRelacionados', $data));
        
    }
    
    public function validaSubs( DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        $data = [];
        $data = $this->produtoEmDistribuicao($row);
        if(!empty($data)) $response->addDataset(new DataSet('produtoEmDistribuicao', $data));
        else{
            $data = $this->produtoReceita($row);
            if(!empty($data)) $response->addDataset(new DataSet('produtoReceita', $data));
            else{
                $data = $this->prodJaConcluido($row);
                if(!empty($data)) $response->addDataset(new DataSet('prodJaConcluido', $data));
            } 
        }
            
    }
    
    public function prodIniciadoProducao(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        $sql = "SELECT NRPLANPROD, CDPRODACABADO, NRSEQPRODACABADO, HRINICIO
                FROM PLANPRODACABADO
                WHERE NRPLANPROD =:NRPLANPROD
                    AND CDPRODACABADO =:CDPRODACABADO
                    AND HRINICIO IS NOT NULL
                    AND IDCOOKCHILL =:IDCOOKCHILL 
                    AND IDTPPRODCHILL =:IDTPPRODCHILL 
                    AND IDFINALIZACAO =:IDFINALIZACAO 
                    AND IDESTADO =:IDESTADO
                    AND NRORG =:NRORG";
        $params = array(
             "NRPLANPROD"         => $row['NRPLANPROD'],
             "CDPRODACABADO"      => $row['CDPRODACABADO'],
             "IDCOOKCHILL"        => $row['IDCOOKCHILL'],
             "IDTPPRODCHILL"      => $row['IDTPPRODCHILL'],
             "IDFINALIZACAO"      => $row['IDFINALIZACAO'],
             "IDESTADO"           => $row['IDESTADO'],
             "NRORG"              => $row['NRORG']
        );
        
        $data = $this->entityManager->getConnection()->fetchAll($sql, $params);
        $response->addDataset(new DataSet('prodIniciadoProducao', $data));
    }
    
    private function produtoEmDistribuicao ($row){
        $sql = "SELECT P.CDPRODACABADO, P.CDFILIAGREG, P.CDSERVFILIAGREG, P.DTCONSUMO, CD.DTCARDAPIO, C.NRDISTPROD
                FROM PLANPRODFILIAGREGA P
                    INNER JOIN CNFDISTCARD DC ON DC.CDPRODPRODUCAO = P.CDPRODACABADO AND NVL(DC.IDEFETIVADA, 'N') <> 'S'
                    INNER JOIN CARDDISTPROD C ON C.NRDISTCARD = DC.NRDISTCARD AND C.CDFILIAL = P.CDFILIAGREG AND C.CDSERVFILI = P.CDSERVFILIAGREG
                    INNER JOIN CARDADIA CD
                    ON CD.DTCARDAPIO = P.DTCONSUMO
                    AND CD.NRCARDAPIO = C.NRCARDAPIO
                    AND CD.CDFILIAL = C.CDFILIAL
                    AND CD.CDSERVFILI = C.CDSERVFILI
                WHERE P.CDPRODACABADO = :CDPRODACABADO
                    AND P.NRPLANPROD = :NRPLANPROD";
        $params = array(
             "NRPLANPROD"   => $row['NRPLANPROD'],
             "CDPRODACABADO" => $row['CDPRODACABADO']
        );
        
        $data = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $data;
    }
    
    private function produtoReceita ($row){
        $sql = "SELECT CDPRODACABADO, CDFILIAGREG, CDSERVFILIAGREG, CDPRODUTO FROM PLANRECPROD
                WHERE NRPLANPROD =:NRPLANPROD AND CDPRODUTO =:CDPRODORIGEM AND CDPRODUTO <> CDPRODACABADO";
        $params = array(
             "NRPLANPROD"   => $row['NRPLANPROD'],
             "CDPRODORIGEM" => $row['CDPRODACABADO']
        );
        
        $data = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $data;
    }
    
    private function prodJaConcluido ($row){
        $sql = "SELECT CDPRODACABADO, NRSEQPRODACABADO, QTAPRODUZIR, HRINICIO, HRFIM 
                FROM PLANPRODACABADO 
                WHERE NRPLANPROD =:NRPLANPROD
                    AND CDPRODACABADO =:CDPRODORIGEM
                    AND (IDCONCLUIDO = 'S' OR HRINICIO IS NOT NULL) ";
        $params = array(
             "NRPLANPROD"   => $row['NRPLANPROD'],
             "CDPRODORIGEM" => $row['CDPRODACABADO']
        );
        
        $data = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $data;
    }
    
    public function validaProdProducao( DTO\Request\Row $request, DTO\Response $response){
        
        $row = $request->getRow();
        
        $sql = "SELECT DISTINCT R.CDPRATO, PPF.CDFILIAGREG, PPF.CDSERVFILIAGREG, S.NMSERVICO, F.NMFILIAL FROM PLANPRODFILIAGREGA PPF 
                INNER JOIN TABLE  (RECEITA_UTIL(PPF.CDFILIAGREG, PPF.CDSERVFILIAGREG, :P_CDPRATO_SEL, :P_CDFILAUXPRAT_SEL, '0', 'Z', NULL, 0, 0, 'S') ) R ON CDPRODPRODUCAO IS NULL
                INNER JOIN SERVICO S ON S.CDFILIAL = PPF.CDFILIAGREG AND S.CDSERVFILI = PPF.CDSERVFILIAGREG AND S.IDSERVATIV = 'S'
                INNER JOIN FILIAL F ON F.CDFILIAL = PPF.CDFILIAGREG
                WHERE PPF.NRPLANPROD = :NRPLANPROD AND PPF.CDPRODACABADO = :CDPRODACABADO AND PPF.IDCOOKCHILL = :IDCOOKCHILL AND PPF.IDTPPRODCHILL = :IDTPPRODCHILL 
                AND PPF.IDFINALIZACAO = :IDFINALIZACAO AND PPF.IDESTADO = :IDESTADO  AND PPF.NRORG = :NRORG AND PPF.NRSEQPRODACABADO = :NRSEQPRODACABADO
                GROUP BY R.CDPRATO, PPF.CDFILIAGREG, PPF.CDSERVFILIAGREG, S.NMSERVICO, F.NMFILIAL";
        $params = array(
             "P_CDPRATO_SEL"      => $row['CDPRATODEST'],
             "P_CDFILAUXPRAT_SEL" => $row['CDFILAUXPRATDEST'],
             "NRPLANPROD"         => $row['NRPLANPROD'],
             "CDPRODACABADO"      => $row['CDPRODACABADO'],
             "IDCOOKCHILL"        => $row['IDCOOKCHILL'],
             "IDTPPRODCHILL"      => $row['IDTPPRODCHILL'],
             "IDFINALIZACAO"      => $row['IDFINALIZACAO'],
             "IDESTADO"           => $row['IDESTADO'],
             "NRORG"              => $row['NRORG'],
             "NRSEQPRODACABADO"   => $row['NRSEQPRODACABADO']
        );

        $data = $this->entityManager->getConnection()->fetchAll($sql, $params);
        $response->addDataset(new DataSet('semReceita', $data));
        
    }
    
    public function validaPermissao( DTO\Request\Row $request, DTO\Response $response){
        
        $row = $request->getRow();
        $cdoperador = $row[0];
        $sql = "SELECT AG.CDGRUPOPER, SUBSTR(G.IDPERMCARD,2,1) PERMITE_ALTERAR, OG.CDOPERADOR
                  FROM AUTGRUPOP AG
                  LEFT JOIN GRUPOPER G ON G.CDGRUPOPER = AG.CDGRUPOPER
                  LEFT JOIN OPERGRUPOP OG ON OG.CDGRUPOPER = G.CDGRUPOPER AND CDOPERADOR = :CDOPERADOR
                WHERE AG.IDAUTGRUPOP = 'SBTP'";
        $params = array(
             "CDOPERADOR"   => $cdoperador
        );
        
        $data = $this->entityManager->getConnection()->fetchAll($sql, $params);
        $response->addDataset(new DataSet('permissao', $data));
    }
    
    private function concatenaValores($row){
        $novaRow = '';
        $novaRow .= $row['CDPRODUTO'];
        $novaRow .= $row['IDCOOKCHILL'];
        $novaRow .= $row['IDFINALIZACAO'];
        $novaRow .= substr($row['IDTPPRODCHILL'],0,1);
        $novaRow .= substr($row['IDESTADO'],0,1);
        $novaRow .= $row['NRSEQPRODACABADO'];
        
        return $novaRow;
    }
    
    private function listaFiliServ ($row){
        $listaServ = [];
        $listaFili = [];
        $sql = "SELECT DISTINCT CDFILIAGREG AS CDFILIAL, (CDFILIAGREG || CDSERVFILIAGREG) AS LISTASERV FROM PLANPRODFILIAGREGA
                 WHERE NRPLANPROD = :NRPLANPROD AND CDPRODACABADO = :CDPRODACABADO 
                 AND IDCOOKCHILL = :IDCOOKCHILL AND IDTPPRODCHILL = :IDTPPRODCHILL 
                 AND IDFINALIZACAO = :IDFINALIZACAO AND IDESTADO = :IDESTADO
                 AND NRORG = :NRORG AND NRSEQPRODACABADO = :NRSEQPRODACABADO";
        $params = [
            "NRPLANPROD"       => $row['NRPLANPROD'],
            "CDPRODACABADO"    => $row['CDPRODUTO'],
            "IDCOOKCHILL"      => $row['IDCOOKCHILL'],
            "IDTPPRODCHILL"    => $row['IDTPPRODCHILL'],
            "IDFINALIZACAO"    => $row['IDFINALIZACAO'],
            "IDESTADO"         => $row['IDESTADO'],
            "NRORG"            => $row['NRORG'],
            "NRSEQPRODACABADO" => $row['NRSEQPRODACABADO']
        ];
        $data = $this->entityManager->getConnection()->fetchAll($sql, $params);
        foreach($data as $row){
            array_push($listaServ,$row['LISTASERV']);
            array_push($listaFili,$row['CDFILIAL']);
        }
        return [$listaServ, $listaFili];
    }
    
    private function dataCard ($row){
         $conditions = array (
                        array (
                            "columnName" => "NRORG",
                            "operator"   => "=",
                            "value"      => $row['NRORG']
                        ),
                        array (
                            "columnName" => "NRPLANPROD",
                            "operator"   => "=",
                            "value"      => $row['NRPLANPROD']
                        )
          );
          $dataSet = $this->crudService->getFilteredDataSet('planproducao', $conditions);
          $result = $dataSet->getRows()[0];
          return $result;
    }
    
    private function verificaCardapio ($row){
        $sql = "SELECT F.CDFILIAL, F.NMFILIAL, S.CDSERVFILI, S.NMSERVICO,
                       LS.DTCARDAPIO, CC.CDPRATO
                  FROM (SELECT DISTINCT CDFILIAGREG AS CDFILIAL, CDSERVFILIAGREG AS CDSERVFILI, 
                               DTCONSUMO AS DTCARDAPIO
                          FROM PLANPRODFILIAGREGA
                         WHERE NRPLANPROD = :NRPLANPROD AND CDPRODACABADO = :CDPRODACABADO 
                           AND IDCOOKCHILL = :IDCOOKCHILL AND IDTPPRODCHILL = :IDTPPRODCHILL 
                           AND IDFINALIZACAO = :IDFINALIZACAO AND IDESTADO = :IDESTADO
                           AND NRORG = :NRORG AND NRSEQPRODACABADO = :NRSEQPRODACABADO) LS
                 INNER JOIN FILIAL F ON F.CDFILIAL = LS.CDFILIAL
                 INNER JOIN SERVICO S ON S.CDFILIAL = LS.CDFILIAL
                                     AND S.CDSERVFILI = LS.CDSERVFILI
                                     AND S.IDSERVATIV = 'S'
                 LEFT JOIN CARDADIA C ON C.CDFILIAL = LS.CDFILIAL
                                     AND C.CDSERVFILI = LS.CDSERVFILI
                                     AND C.DTCARDAPIO = LS.DTCARDAPIO
                 LEFT JOIN COMPCARD CC ON CC.NRCARDAPIO = C.NRCARDAPIO
                                      AND CC.CDFILIAL = C.CDFILIAL
                                      AND CC.CDPRATO = :CDPRATO
                                      AND CC.CDFILAUXPRAT = :CDFILAUX
                 WHERE CC.CDPRATO IS NULL";
        $params = [
            "CDPRATO"          => $row['CDPRATOORI'],
            "CDFILAUX"         => $row['CDFILAUXPRATORI'],
            "NRPLANPROD"       => $row['NRPLANPROD'],
            "CDPRODACABADO"    => $row['CDPRODUTO'],
            "IDCOOKCHILL"      => $row['IDCOOKCHILL'],
            "IDTPPRODCHILL"    => $row['IDTPPRODCHILL'],
            "IDFINALIZACAO"    => $row['IDFINALIZACAO'],
            "IDESTADO"         => $row['IDESTADO'],
            "NRORG"            => $row['NRORG'],
            "NRSEQPRODACABADO" => $row['NRSEQPRODACABADO']
        ];
        
        return $this->entityManager->getConnection()->fetchAll($sql, $params);
    }
    

}